(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[      4966,        143]
NotebookOptionsPosition[      4692,        129]
NotebookOutlinePosition[      5031,        144]
CellTagsIndexPosition[      4988,        141]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<NETLink`\>\"", "]"}], "\n", 
 RowBox[{"LoadNETAssembly", "[", 
  RowBox[{"\"\<Tinkerforge\>\"", ",", 
   RowBox[{
    RowBox[{"NotebookDirectory", "[", "]"}], "<>", "\"\<../../..\>\""}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.6435440394946423`*^9, 3.643544043128192*^9}}],

Cell[BoxData[{
 RowBox[{"host", "=", "\"\<localhost\>\""}], "\n", 
 RowBox[{"port", "=", "4223"}], "\n", 
 RowBox[{
  RowBox[{"uid", "=", "\"\<XYZ\>\""}], 
  RowBox[{"(*", 
   RowBox[{"Change", " ", "to", " ", "your", " ", "UID"}], "*)"}], "\n", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Create", " ", "IPConnection", " ", "and", " ", "device", " ", "object"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"ipcon", "=", 
  RowBox[{"NETNew", "[", "\"\<Tinkerforge.IPConnection\>\"", "]"}]}], "\n", 
 RowBox[{"a", "=", 
  RowBox[{"NETNew", "[", 
   RowBox[{
   "\"\<Tinkerforge.BrickletAccelerometer\>\"", ",", "uid", ",", "ipcon"}], 
   "]"}]}], "\n", 
 RowBox[{
  RowBox[{"ipcon", "@", 
   RowBox[{"Connect", "[", 
    RowBox[{"host", ",", "port"}], "]"}]}], "\n", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Callback", " ", "function", " ", "for", " ", "acceleration", " ", 
    "callback", " ", 
    RowBox[{"(", 
     RowBox[{"parameters", " ", "have", " ", "unit", " ", 
      RowBox[{"g", "/", "1000"}]}], ")"}]}], "*)"}]}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{
   RowBox[{"AccelerationCB", "[", 
    RowBox[{"sender_", ",", "x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{"\"\<Acceleration[X]: \>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{"N", "[", 
          RowBox[{"Quantity", "[", 
           RowBox[{"x", ",", "\"\<g/1000\>\""}], "]"}], "]"}], "]"}]}], "]"}],
       ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<Acceleration[Y]: \>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{"N", "[", 
          RowBox[{"Quantity", "[", 
           RowBox[{"y", ",", "\"\<g/1000\>\""}], "]"}], "]"}], "]"}]}], "]"}],
       ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<Acceleration[Z]: \>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{"N", "[", 
          RowBox[{"Quantity", "[", 
           RowBox[{"z", ",", "\"\<g/1000\>\""}], "]"}], "]"}], "]"}]}], 
       "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AddEventHandler", "[", 
   RowBox[{
    RowBox[{"a", "@", "Acceleration"}], ",", "AccelerationCB"}], "]"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Set", " ", "period", " ", "for", " ", "acceleration", " ", "callback", 
    " ", "to", " ", "1", "s", " ", 
    RowBox[{"(", 
     RowBox[{"1000", "ms"}], ")"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Note", ":", 
    RowBox[{
    "The", " ", "acceleration", " ", "callback", " ", "is", " ", "only", " ", 
     "called", " ", "every", " ", "second"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "if", " ", "the", " ", "acceleration", " ", "has", " ", "changed", " ", 
    "since", " ", "the", " ", "last", " ", 
    RowBox[{"call", "!"}]}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{"a", "@", 
   RowBox[{"SetAccelerationCallbackPeriod", "[", "1000", "]"}]}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Input", "[", "\"\<Click OK to exit\>\"", "]"}], "\n", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Clean", " ", "up"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"ipcon", "@", 
  RowBox[{"Disconnect", "[", "]"}]}], "\n", 
 RowBox[{"ReleaseNETObject", "[", "a", "]"}], "\n", 
 RowBox[{"ReleaseNETObject", "[", "ipcon", "]"}]}], "Input",
 CellChangeTimes->{{3.643544050590163*^9, 3.643544103419498*^9}, {
  3.6441444313391314`*^9, 3.64414443271782*^9}, {3.644144731633753*^9, 
  3.6441447327759323`*^9}, {3.6514681774238663`*^9, 3.6514681824691963`*^9}}]
},
WindowSize->{1189, 844},
WindowMargins->{{Automatic, 226}, {Automatic, 24}},
FrontEndVersion->"9.0 for Linux x86 (64-bit) (November 20, 2012)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 320, 7, 55, "Input"],
Cell[880, 29, 3808, 98, 671, "Input"]
}
]
*)

(* End of internal cache information *)
